pub trait FoundryChain<Tx>:
Clone
+ Debug
+ Default
+ Send
+ Sync {
// Provided methods
fn for_transaction(_tx: &Tx) -> Self { ... }
fn for_block(
_grandparent: &[Tx],
_parent: &[Tx],
_current: &[Tx],
_current_tx_index: usize,
) -> Self { ... }
fn refresh_journal<J: FoundryJournal>(&self, _journal: &mut J) { ... }
fn clear_transaction_fee_cache(&mut self) { ... }
}Expand description
Foundry extension for chain context type
Every family that doesn’t need chain metadata uses ().
Provided Methods
Sourcefn for_transaction(_tx: &Tx) -> Self
fn for_transaction(_tx: &Tx) -> Self
Builds chain context for a standalone synthetic transaction.
Sourcefn for_block(
_grandparent: &[Tx],
_parent: &[Tx],
_current: &[Tx],
_current_tx_index: usize,
) -> Self
fn for_block( _grandparent: &[Tx], _parent: &[Tx], _current: &[Tx], _current_tx_index: usize, ) -> Self
Builds chain context for a transaction at an exact block position.
Sourcefn refresh_journal<J: FoundryJournal>(&self, _journal: &mut J)
Available on crate feature monad only.
fn refresh_journal<J: FoundryJournal>(&self, _journal: &mut J)
monad only.Refreshes journal state derived from the active chain position.
Sourcefn clear_transaction_fee_cache(&mut self)
fn clear_transaction_fee_cache(&mut self)
Clears cached protocol fees after a synthetic transaction restores chain context.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl FoundryChain<BaseTransaction<TxEnv>> for L1BlockInfo
Available on crate feature base only.
impl FoundryChain<BaseTransaction<TxEnv>> for L1BlockInfo
Available on crate feature
base only.fn clear_transaction_fee_cache(&mut self)
Sourceimpl FoundryChain<OpTx> for L1BlockInfo
Available on crate feature optimism only.
impl FoundryChain<OpTx> for L1BlockInfo
Available on crate feature
optimism only.fn clear_transaction_fee_cache(&mut self)
Sourceimpl FoundryChain<TxEnv> for MonadChainContext
Available on crate feature monad only.
impl FoundryChain<TxEnv> for MonadChainContext
Available on crate feature
monad only.